@@ -44,6 +44,7 @@
 #' @param legend_full If plotting a linear pool, set \code{ind = TRUE} for each expert
 #' to be plotted with a different colour, and \code{ind = FALSE} for each expert to be 
 #' plotted with the same colour, reducing the legend size.
+#' @param percentages Set to \code{TRUE} to use percentages on the x-axis. 
 #' @author Jeremy Oakley <j.oakley@@sheffield.ac.uk>
 #' @examples
 #' 
@@ -95,7 +96,8 @@ plotfit <- function(fit,
                     lwd = 1,
                     xlab = "x",
                     ylab = expression(f[X](x)),
-                    legend_full = TRUE){
+                    legend_full = TRUE,
+                    percentages = FALSE){
   
 
   if(d=="beta" & (min(fit$limits) == -Inf | max(fit$limits) == Inf )){stop("Parameter limits must be finite to fit a beta distribution")}
@@ -129,7 +131,8 @@ plotfit <- function(fit,
       f2 <- feedback(fit, quantiles=0.99, dist=d)
       xu <- max(f2$expert.quantiles)
     }
-    if(int == FALSE){print(makeLinearPoolPlot(fit, xl, xu,  d , lpw, lwd, xlab, ylab, legend_full))}else{
+    if(int == FALSE){print(makeLinearPoolPlot(fit, xl, xu,  d , lpw,
+                                              lwd, xlab, ylab, legend_full))}else{
       shinyplotgroup(fit, xl, xu, lpw, lwd, xlab, ylab, legend_full)
     }
     
@@ -138,18 +141,30 @@ plotfit <- function(fit,
   if(nrow(fit$vals)>1 & is.na(ex)==F){
     if(xl == -Inf & fit$limits[ex,1] > -Inf){xl <- fit$limits[ex,1] }
     if(xu == Inf & fit$limits[ex,2] < Inf){xu <- fit$limits[ex,2] }
-    if(int == FALSE){suppressWarnings(print(makeSingleExpertPlot(fit, d, xl, xu, 
-                                                                 ql, qu, sf, ex = 1, 
-                                                                 lwd, xlab, ylab)))}else{
-      shinyplotsingle(fit, xl, xu, ql, qu, ex, xlab, ylab)
+    if(int == FALSE){suppressWarnings(print(makeSingleExpertPlot(fit, d, 
+                                                                 xl, xu, 
+                                                                 ql, qu, 
+                                                                 sf, ex = 1, 
+                                                                 lwd, xlab, 
+                                                                 ylab,
+                                                                 percentages)
+                                            )
+                                      )
+      }else{
+      shinyplotsingle(fit, xl, xu, ql, qu, ex, xlab, ylab, percentages)
     }
     
   }
   
  
   if(nrow(fit$vals)==1){
-    if(int == FALSE){print(suppressWarnings(makeSingleExpertPlot(fit, d, xl, xu, ql, qu, sf, ex = 1, lwd, xlab, ylab)))}else{
-      suppressWarnings(shinyplotsingle(fit, xl, xu, ql, qu, ex = 1, xlab, ylab))
+    if(int == FALSE){
+      print(suppressWarnings(makeSingleExpertPlot(fit, d, xl, 
+                                                  xu, ql, qu, sf, ex = 1,
+                                                  lwd, xlab, ylab,
+                                                  percentages)))}else{
+      suppressWarnings(shinyplotsingle(fit, xl, xu, ql, qu, ex = 1,
+                                       xlab, ylab, percentages))
     }
   }
 
